CIMA Library to process GOES 16 data
====================================

This project is a client library to download and process Geostationary Operational Environmental Satellite data

CIMA - CONICET - UBA - Argentina


|pythons| |pypibq|


Installation
------------

.. code-block:: console

    $ pip install --upgrade cima.goes

.. _CIMA GOES: https://pypi.org/project/cima.goes/

.. |pypibq| image:: https://img.shields.io/pypi/v/gcloud-aio-bigquery.svg?style=flat-square
    :alt: Latest PyPI Version
    :target: https://pypi.org/project/cima.goes/

.. |pythons| image:: https://img.shields.io/pypi/pyversions/gcloud-aio-auth.svg?style=flat-square
    :alt: Python Version Support
    :target: https://pypi.org/project/cima.goes/